==> intel-media-driver-non-free_25.1.2+ds1.orig.tar.xz: media-driver-intel-media-25.1.2/media_softlet/agnostic/Xe3_M_plus/Xe3_LPM_base/hw/vdbox/media_srcs.cmake <==
# Copyright (c) 2024, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_xe3_lpm_base.h
)

set(SOFTLET_MHW_VDBOX_COMMON_HEADERS_
    ${SOFTLET_COMMON_HEADERS_}
    ${TMP_HEADERS_}
)

set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vvcp_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_impl_xe3_lpm_base_open.h
)

set(SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_HCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${SOFTLET_MHW_VDBOX_HUC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${SOFTLET_MHW_VDBOX_AVP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${SOFTLET_MHW_VDBOX_MFX_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VVCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
)

source_group( "MHW Next\\Xe3_M_Plus\\Vdbox" FILES ${TMP_SOURCES_} ${TMP_HEADERS_} 
    ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
)

set(TMP_HEADERS_ "")

set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_VVCPHEADERS_ "")

set(SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)

==> intel-media-driver-non-free_25.3.4+ds1.orig.tar.xz: media-driver-intel-media-25.3.4/media_softlet/agnostic/Xe3_M_plus/Xe3_LPM_base/hw/vdbox/media_srcs.cmake <==
# Copyright (c) 2024, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_xe3_lpm_base.h
)

set(SOFTLET_MHW_VDBOX_COMMON_HEADERS_
    ${SOFTLET_COMMON_HEADERS_}
    ${TMP_HEADERS_}
)

set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_hcp_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_huc_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_avp_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_mfx_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vvcp_impl_xe3_lpm_base.h
)

set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/mhw_vdbox_vdenc_impl_xe3_lpm_base.h
)

set(SOFTLET_MHW_VDBOX_HCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_HCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_HUC_HEADERS_
    ${SOFTLET_MHW_VDBOX_HUC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_AVP_HEADERS_
    ${SOFTLET_MHW_VDBOX_AVP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_MFX_HEADERS_
    ${SOFTLET_MHW_VDBOX_MFX_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VVCP_HEADERS_
    ${SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
)

set(SOFTLET_MHW_VDBOX_VDENC_HEADERS_
    ${SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
)

source_group( "MHW Next\\Xe3_M_Plus\\Vdbox" FILES ${TMP_SOURCES_} ${TMP_HEADERS_} 
    ${TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VVCP_HEADERS_}
    ${TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_}
)

set(TMP_HEADERS_ "")

set(TMP_SOFTLET_MHW_VDBOX_VDENC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HCP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_HUC_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_AVP_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_MFX_HEADERS_ "")
set(TMP_SOFTLET_MHW_VDBOX_VVCPHEADERS_ "")

set(SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_MHW_VDBOX_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
